/* ************************************************************************** */
/*                                       _____           _                    */
/*  libg1m/format/fkey.h                |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libg1m                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/12/16 16:04:58                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#ifndef LIBG1M_FORMAT_FKEY_H
# define LIBG1M_FORMAT_FKEY_H
# include <libg1m.h>
# pragma pack(1)

/*	Function keys are the little boxes at the bottom with text in it, to tell
 *	you what you're going to access if you press F1-F6. */
/* ************************************************************************** */
/*  G1N - Function-keys files for fx calculators                              */
/* ************************************************************************** */
/*	In G1Ns, function keys are 19x8 1-bit with fill bits images.
 *
 *	TODO: it is unknown yet how to identify G1N files, as no non-community-made
 *	one of them was found and the calculator software just skips
 *	StandardHeader. It has to be found for a correct integration in libg1m!
 *
 *	The format looks a lot like G1L files. The header is the following: */

# define FKEY_WIDTH 24
# define FKEY_HEIGHT 8
struct g1n_subheader {
	/* usually "PowerUSB" */
	uint8_t identifier[8];

	/* useless data */
	uint8_t _useless[4];

	/* number of icons */
	uint16_t fkey_count;
};

/*	Then there is a table of 16-bits offsets (iconXXX - icon0), then the icons.
 *	The first "icon" is in fact the name of the language. */
/* ************************************************************************** */
/*  G3L-N - Function-keys files for CG calculators                            */
/* ************************************************************************** */
/*	G3L-N have exactly the same header and subheader as G3Ls, except
 *	the magic field is "0201" and not "0401" like for "normal" G3Ls.
 *
 *	TODO: it is unknown yet how to identify G3N files using the StandardHeader,
 *	as no non-community-made one of them was found and the calculator software
 *	just skips StandardHeader. It has to be found for a correct integration
 *	in libg1m!
 *
 *	In G3L-Ns, function keys are 64x24 1-bit images. */

# define FKEY3_WIDTH 64
# define FKEY3_HEIGHT 24
# pragma pack()
#endif /* LIBG1M_FORMAT_FKEY_H */
